# PassGen Python CLI

## Download for use
- Requires python >= 3.6.
- Install from PyPI using `$ pip install passgen-py`
- Run `passgen --help`

## Setup for Development
- Requires [pipenv](https://pypi.org/project/pipenv/) and python3.7
- Setup the requirements using `$ make bootstrap`
- Run the tests using `$ make test`
- Run the CLI using `$ pipenv run passgen` 
